@@ -1,41 +1,31 @@
 ﻿#  -*- coding: utf-8 -*-
-#   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
-#  #
-#   This program is free software: you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
-#   (at your option) any later version.
-#  #
-#   This program is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
-#  #
-#   You should have received a copy of the GNU General Public License
-#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: MPL-2.0
+# Copyright 2020-2021 John Mille <john@compose-x.io>
 
+"""
+Module to define CloudWatch alarms in x-alarms and match these to services
+"""
 
-from troposphere import Ref, GetAtt
 from troposphere import Output
-from troposphere.cloudwatch import Alarm as CWAlarm
+from troposphere import Ref, GetAtt
+from troposphere.cloudwatch import Alarm as CWAlarm, CompositeAlarm, MetricDimension
 
 from ecs_composex.common import LOG
 from ecs_composex.common import keyisset, add_parameters, add_outputs
 from ecs_composex.common.cfn_params import Parameter
-from ecs_composex.resources_import import import_record_properties
 from ecs_composex.ecs.ecs_params import SERVICE_SCALING_TARGET
 from ecs_composex.ecs.ecs_scaling import (
     generate_alarm_scaling_out_policy,
     reset_to_zero_policy,
 )
+from ecs_composex.ecs.ecs_params import SERVICE_T, CLUSTER_NAME
 from ecs_composex.sns.sns_params import (
     RES_KEY as SNS_KEY,
-    MOD_KEY as SNS_MKEY,
     TOPIC_ARN_RE,
     TOPIC_ARN,
 )
 from ecs_composex.sns.sns_stack import Topic
+from ecs_composex.alarms.alarms_stack import create_alarms, Alarm
 
 
 def get_alarm_actions(alarm):
@@ -90,56 +80,45 @@ def add_service_actions(
         ),
     )
     if not alarm.cfn_resource:
-        if not alarm.properties:
-            raise KeyError("You defined an Alarm without any properties")
-        props = import_record_properties(alarm.properties, CWAlarm)
-        props.update(
-            {
-                "OKActions": [Ref(scaling_in_policy)],
-                "AlarmActions": [Ref(scaling_out_policy)],
-            }
-        )
-        alarm.cfn_resource = CWAlarm(alarm.logical_name, **props)
-        target[0].template.add_resource(alarm.cfn_resource)
-    else:
-        service_scaling_in_policy_param = Parameter(
-            f"{target[0].logical_name}ScaleInPolicy", Type="String"
-        )
-        service_scaling_out_policy_param = Parameter(
-            f"{target[0].logical_name}ScaleOutPolicy", Type="String"
-        )
-        add_parameters(
-            alarms_stack.stack_template,
-            [service_scaling_in_policy_param, service_scaling_out_policy_param],
-        )
-        add_outputs(
-            target[0].template,
-            [
-                Output(
-                    f"{target[0].logical_name}ScaleInPolicy",
-                    Value=Ref(scaling_in_policy),
-                ),
-                Output(
-                    f"{target[0].logical_name}ScaleOutPolicy",
-                    Value=Ref(scaling_out_policy),
-                ),
-            ],
-        )
-        alarms_stack.Parameters.update(
-            {
-                service_scaling_in_policy_param.title: GetAtt(
-                    target[0].logical_name,
-                    f"Outputs.{target[0].logical_name}ScaleInPolicy",
-                ),
-                service_scaling_out_policy_param.title: GetAtt(
-                    target[0].logical_name,
-                    f"Outputs.{target[0].logical_name}ScaleOutPolicy",
-                ),
-            }
-        )
-        actions = get_alarm_actions(alarm)
-        actions[0].append(Ref(service_scaling_in_policy_param))
-        actions[1].append(Ref(service_scaling_out_policy_param))
+        raise AttributeError(f"Alarm {alarm.logical_name} has no CFN object associated")
+    service_scaling_in_policy_param = Parameter(
+        f"{target[0].logical_name}ScaleInPolicy", Type="String"
+    )
+    service_scaling_out_policy_param = Parameter(
+        f"{target[0].logical_name}ScaleOutPolicy", Type="String"
+    )
+    add_parameters(
+        alarms_stack.stack_template,
+        [service_scaling_in_policy_param, service_scaling_out_policy_param],
+    )
+    add_outputs(
+        target[0].template,
+        [
+            Output(
+                f"{target[0].logical_name}ScaleInPolicy",
+                Value=Ref(scaling_in_policy),
+            ),
+            Output(
+                f"{target[0].logical_name}ScaleOutPolicy",
+                Value=Ref(scaling_out_policy),
+            ),
+        ],
+    )
+    alarms_stack.Parameters.update(
+        {
+            service_scaling_in_policy_param.title: GetAtt(
+                target[0].logical_name,
+                f"Outputs.{target[0].logical_name}ScaleInPolicy",
+            ),
+            service_scaling_out_policy_param.title: GetAtt(
+                target[0].logical_name,
+                f"Outputs.{target[0].logical_name}ScaleOutPolicy",
+            ),
+        }
+    )
+    actions = get_alarm_actions(alarm)
+    actions[0].append(Ref(service_scaling_in_policy_param))
+    actions[1].append(Ref(service_scaling_out_policy_param))
 
 
 def handle_service_scaling(alarm, alarms_stack):
@@ -202,7 +181,7 @@ def handle_notify_on(topic_def):
     valid_values = ["all", "okay", "alarm"]
     notify_on = "alarm"
     if not keyisset("NotifyOn", topic_def):
-        LOG.warning("NotifyOn was not set for topic. Will default to Alarms")
+        LOG.warning("NotifyOn was not set for topic. Will default to AlarmActions")
     else:
         if not isinstance(topic_def["NotifyOn"], str):
             raise TypeError("NotifyOn must be a string")
@@ -287,6 +266,84 @@ def alarms_to_ecs(resources, services_stack, res_root_stack, settings):
         if not resource.lookup and not resource.use
     ]
     for alarm in new_resources:
+        if alarm.in_composite:
+            continue
         handle_service_scaling(alarm, res_root_stack)
         if alarm.topics:
             handle_alarm_topics(alarm, res_root_stack, settings)
+
+
+def update_alarm_threshold(alarm_properties, settings):
+    """
+    Function to update the threshold based on the defined settings
+
+    :param alarm_properties:
+    :param settings:
+    :return:
+    """
+    if alarm_properties["MetricName"] in settings and keyisset(
+        alarm_properties["MetricName"], settings
+    ):
+        alarm_properties["Threshold"] = float(settings[alarm_properties["MetricName"]])
+
+
+def update_definition_from_settings(alarm_definition, settings):
+    """
+    Function to update the alarm definition with the global settings
+
+    :param dict alarm_definition:
+    :param dict settings:
+    :return:
+    """
+    alarm_definition["Properties"].update(
+        {
+            "DatapointsToAlarm": settings["DatapointsToAlarm"],
+            "EvaluationPeriods": settings["EvaluationPeriods"],
+            "Period": settings["Period"],
+        }
+    )
+
+
+def set_services_alarms(settings):
+    """
+    Function to create and assign alarms to services
+
+    :param ecs_composex.common.settings.ComposeXSettings settings:
+    :return:
+    """
+    for family in settings.families.values():
+        if not family.predefined_alarms:
+            continue
+        family_alarms = []
+        for name, definition in family.predefined_alarms.items():
+            primary_name = definition["Primary"]
+            primary = definition["Alarms"][primary_name]
+            update_definition_from_settings(primary, definition["Settings"])
+            for alarm_name, alarm_definition in definition["Alarms"].items():
+                if keyisset("Topics", definition):
+                    alarm_definition["Topics"] = definition["Topics"]
+                if keyisset("Properties", alarm_definition) and keyisset(
+                    "MetricName", alarm_definition["Properties"]
+                ):
+                    update_alarm_threshold(
+                        alarm_definition["Properties"], definition["Settings"]
+                    )
+                the_alarm = Alarm(
+                    alarm_name, alarm_definition, family.logical_name, settings
+                )
+                family_alarms.append(the_alarm)
+        create_alarms(family.template, settings, family_alarms)
+        for alarm in family_alarms:
+            dimensions = [
+                MetricDimension(**{"Name": "ClusterName", "Value": Ref(CLUSTER_NAME)}),
+                MetricDimension(
+                    **{
+                        "Name": "ServiceName",
+                        "Value": GetAtt(family.ecs_service.ecs_service, "Name"),
+                    }
+                ),
+            ]
+            if isinstance(alarm.cfn_resource, CWAlarm):
+                setattr(alarm.cfn_resource, "Dimensions", dimensions)
+            if issubclass(type(alarm.cfn_resource), CompositeAlarm):
+                handle_alarm_topics(alarm, family.stack, settings)
