@@ -1,19 +1,6 @@
-# -*- coding: utf-8 -*-
-#  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020-2021  John Mille <john@compose-x.io>
-#
-#  This program is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#  -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MPL-2.0
+# Copyright 2020-2021 John Mille <john@compose-x.io>
 
 """
 Functions to build the ECS Service Definition
@@ -37,7 +24,7 @@ from troposphere.ecs import (
     NetworkConfiguration,
     DeploymentController,
     DeploymentConfiguration,
-    DeploymentCircuitBreaker,
+    DeploymentCircuitBreaker as EcsDeploymentCircuitBreaker,
 )
 from troposphere.ecs import ServiceRegistry
 from troposphere.elasticloadbalancingv2 import (
@@ -348,14 +335,16 @@ def define_deployment_options(family, settings, kwargs):
     """
     family.set_service_update_config()
     default = DeploymentConfiguration(
-        DeploymentCircuitBreaker=DeploymentCircuitBreaker(Enable=True, RollBack=True),
+        DeploymentCircuitBreaker=EcsDeploymentCircuitBreaker(
+            Enable=True, Rollback=True
+        ),
     )
     if family.deployment_config:
         deploy_config = DeploymentConfiguration(
             MaximumPercent=family.deployment_config["MaximumPercent"],
             MinimumHealthyPercent=family.deployment_config["MinimumHealthyPercent"],
-            DeploymentCircuitBreaker=DeploymentCircuitBreaker(
-                Enable=True, RollBack=keyisset("RollBack", family.deployment_config)
+            DeploymentCircuitBreaker=EcsDeploymentCircuitBreaker(
+                Enable=True, Rollback=keyisset("RollBack", family.deployment_config)
             ),
         )
         kwargs.update({"DeploymentConfiguration": deploy_config})
@@ -389,6 +378,9 @@ class Service(object):
         self.network_settings = None
         self.ecs_service = None
         self.scalable_target = None
+        self.scaling_out_policies = {}
+        self.scaling_in_policies = {}
+        self.alarms = {}
         family.stack_parameters.update({ecs_params.SERVICE_NAME_T: family.name})
         self.sgs = []
         self.sg = add_service_default_sg(family.template)
