@@ -1,19 +1,6 @@
 #  -*- coding: utf-8 -*-
-#   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020  John Mille <john@compose-x.io>
-#  #
-#   This program is free software: you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
-#   (at your option) any later version.
-#  #
-#   This program is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
-#  #
-#   You should have received a copy of the GNU General Public License
-#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: MPL-2.0
+# Copyright 2020-2021 John Mille <john@compose-x.io>
 
 """
 Main module. Implements all the logic of the macro event parsing and generating.
@@ -25,7 +12,7 @@ import requests
 import boto3
 import tempfile
 import yaml
-from os import path
+from os import path, environ
 from copy import deepcopy
 from urllib.parse import urlparse
 
@@ -106,6 +93,22 @@ def init_settings_params(settings_params, fragment, request_id, folder):
     return new_fragment
 
 
+def define_s3_bucket_upload(settings, params):
+    """
+    Function to override the buckets settings before rendering
+    Priority goes to BucketName if defined in the CFN template in the macro Parameters
+    Fall back to env var UPLOAD_BUCKET_NAME if set, else, sticks to default behaviour
+    """
+    if keyisset(settings.bucket_arg, params):
+        settings.bucket_name = params["BucketName"]
+        LOG.info(f"Overriding bucket name to {settings.bucket_name}")
+    elif environ.get("UPLOAD_BUCKET_NAME"):
+        settings.bucket_name = environ.get("UPLOAD_BUCKET_NAME")
+        LOG.info(
+            f"Found BUCKET_NAME defined in the environment variables. Setting to {settings.bucket_name}"
+        )
+
+
 def lambda_handler(event, context):
     """
     Lambda function entrypoint.
@@ -129,6 +132,7 @@ def lambda_handler(event, context):
     new_fragment = init_settings_params(settings_params, fragment, request_id, folder)
     settings = ComposeXSettings(for_macro=True, **settings_params)
     settings.set_bucket_name_from_account_id()
+    define_s3_bucket_upload(settings, params)
     settings.set_azs_from_api()
     settings.deploy = True
     settings.upload = True
