@@ -1,4 +1,7 @@
-﻿#!/usr/bin/env python
+﻿#  -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MPL-2.0
+# Copyright 2020-2021 John Mille<john@compose-x.io>
+
 """
 Module to deployment with compute resources
 """
